datapipe v0.1.0-rc1 (2025-04-17)
--------------------------------

This is the first (pre)release of the datapipe package.

New Features
~~~~~~~~~~~~

- CWL workflows covering UC-DPPS-130-1.2, 1.2.1, and 1.2.2
